#
# spec file for package python-pycapnp
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pycapnp
Version:        1.3.0
Release:        1.1
Summary:        Cython wrapping of the C++ Cap'n Proto library
License:        BSD-2-Clause
URL:            https://github.com/capnproto/pycapnp
Source:         https://github.com/capnproto/pycapnp/archive/refs/tags/v%{version}.tar.gz#/pycapnp-%{version}.tar.gz
BuildRequires:  %{python_module Cython with %python-Cython < 3}
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pkgconfig}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(capnp)
%python_subpackages

%description
A cython wrapping of the C++ Cap'n Proto library.

%prep
%setup -q -n pycapnp-%{version}
sed -i '1{/^#!/d}' capnp/templates/setup.py.tmpl

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/capnpc-cython
%{python_expand rm %{buildroot}%{$python_sitearch}/capnp/helpers/*.h
%fdupes %{buildroot}%{$python_sitearch}
}
%python_expand find %{buildroot}%{$python_sitearch}

%check
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitearch}
mv capnp/ /tmp
if [[ "$python" == "python3" || "$python" == "python3.6" ]]; then
  $python -m pytest -k 'not async'
else
  $python -m pytest
fi
mv /tmp/capnp/ .
}

%post
%python_install_alternative capnpc-cython

%postun
%python_uninstall_alternative capnpc-cython

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE.md
%python_alternative %{_bindir}/capnpc-cython
%{python_sitearch}/*

%changelog
* Sun Aug 13 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.0:
  * Update to bundled capnproto-0.10.3
  * Add Python 3.11
  * Prevent race condition in example code (#305)
* Wed Dec  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v1.2.2
  * Update bundled bundled capnp to 0.8.1 due to CVE-2022-46149
  * This only affects pycapnp if you're using bundled capnp (otherwise
  just update libcapnp)
  * pypi packages are affected
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v1.2.1
  * Fix packaging for Apple Silicon
* Tue Oct  4 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v1.2.0 (2022-08-29)
  Added support for Apple Silicon
- Update to v1.1.1 (2022-05-23)
  Added Python 3.10 support
  aarch64 wheel support
  Fix doc string for _DynamicResizableListBuilder
  fix for unreleased buffers under mmap (issue 280)
- Update to v1.1.0 (2021-06-09)
  Validated compatibility with Python 3.10.0b2
  Remove all bare except
  Improve _StructModuleWhich to inherit from enum.Enum
  Add Union on top level union messages
  Fixed memory leak in _SegmentArrayMessageReader
  Removed many pycodestyle warnings
  Avoid crash if __file__ is not set by importer
  Fixed module.pyx _set_<field> for boolean fields
  Fixed setup.py.tmpl support for *.c++ files
  Fixed _gen.py for python3 as dict_keys object are not indexable.
  Add test data to sdist
  Add pyproject.yaml
  Add missing inheritance to _Schema for _StructSchema
* Wed Mar 10 2021 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.0.0
